@@ -30,26 +30,26 @@
 #' @examples
 #' \donttest{
 #' ## Simulate mixture data:
-#' mixt1 <- twoComp_mixt(n = 2600, weight = 0.8,
+#' mixt1 <- twoComp_mixt(n = 1600, weight = 0.8,
 #'                       comp.dist = list("gamma", "exp"),
 #'                       comp.param = list(list("shape" = 16, "scale" = 1/4),
 #'                                         list("rate" = 1/3.5)))
-#' mixt2 <- twoComp_mixt(n = 3000, weight = 0.7,
+#' mixt2 <- twoComp_mixt(n = 2000, weight = 0.7,
 #'                       comp.dist = list("gamma", "exp"),
 #'                       comp.param = list(list("shape" = 14, "scale" = 1/2),
 #'                                         list("rate" = 1/5)))
-#' mixt3 <- twoComp_mixt(n = 3500, weight = 0.6,
+#' mixt3 <- twoComp_mixt(n = 2500, weight = 0.6,
 #'                       comp.dist = list("gamma", "gamma"),
 #'                       comp.param = list(list("shape" = 16, "scale" = 1/4),
 #'                                         list("shape" = 12, "scale" = 1/2)))
-#' mixt4 <- twoComp_mixt(n = 4800, weight = 0.5,
+#' mixt4 <- twoComp_mixt(n = 3800, weight = 0.5,
 #'                       comp.dist = list("gamma", "exp"),
 #'                       comp.param = list(list("shape" = 14, "scale" = 1/2),
 #'                                         list("rate" = 1/7)))
-#' data1 <- getmixtData(mixt1)
-#' data2 <- getmixtData(mixt2)
-#' data3 <- getmixtData(mixt3)
-#' data4 <- getmixtData(mixt4)
+#' data1 <- get_mixture_data(mixt1)
+#' data2 <- get_mixture_data(mixt2)
+#' data3 <- get_mixture_data(mixt3)
+#' data4 <- get_mixture_data(mixt4)
 #' ## Define the admixture models:
 #' admixMod1 <- admix_model(knownComp_dist = mixt1$comp.dist[[2]],
 #'                          knownComp_param = mixt1$comp.param[[2]])
@@ -62,7 +62,7 @@
 #' ## Clustering procedure:
 #' admix_cluster(samples = list(data1, data2, data3, data4),
 #'               admixMod = list(admixMod1, admixMod2, admixMod3, admixMod4),
-#'               conf_level = 0.95, tune_penalty = TRUE, n_sim_tab = 30)
+#'               conf_level = 0.95, tune_penalty = TRUE, n_sim_tab = 10)
 #' }
 #'
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
@@ -71,6 +71,8 @@
 admix_cluster <- function(samples, admixMod, conf_level = 0.95, tune_penalty = TRUE,
                           tabul_dist = NULL, echo = TRUE, ...)
 {
+  if (!is.list(samples))
+    stop("Please provide sample(s) and admixture model(s) in lists!")
   if (!all(sapply(X = admixMod, FUN = inherits, what = "admix_model")))
     stop("Argument 'admixMod' is not correctly specified. See ?admix_model.")
 
@@ -323,4 +325,3 @@ summary.admix_cluster <- function(object, ...)
   cat("\n\nMatrix of discrepancies between samples (used for clustering):\n")
   print(object$discrepancy_matrix)
 }
-
