@@ -56,7 +56,7 @@
 admix_test <- function(samples, admixMod, test_method = c("poly","icv"), conf_level = 0.95, ...)
 {
   if (!is.list(samples))
-    stop("Please provide sample(s) and admixture model(s) in lists, also with only one sample!")
+    stop("Please provide sample(s) and admixture model(s) in a list, also with only one sample!")
   if (!all(sapply(X = admixMod, FUN = inherits, what = "admix_model")))
     stop("Argument 'admixMod' is not correctly specified. See ?admix_model.")
 
@@ -68,9 +68,9 @@ admix_test <- function(samples, admixMod, test_method = c("poly","icv"), conf_le
   if ((n_samples == 1) & (meth == "icv")) stop("Testing using the inner convergence property (obtained from IBM estimation) requires at least TWO samples.\n")
   if (meth == "poly") message("  Testing using polynomial basis expansions requires in theory a square-root n consistent estimation
   of the proportions of the unknown component distributions (thus using 'BVdk' estimation by default,
-  associated to unknown component distributions with symmetric densities). However, it is allowed to
-  use 'PS' estimation in practice (argument 'est_method' has therefore to be set to 'PS'. In this case,
-  the variance of estimators is obtained by boostrapping.\n")
+  associated to unknown component distributions with symmetric densities). However, for practical
+  considerations, it is allowed to use 'PS' estimator in the 2-sample case (argument 'est_method' has
+  therefore to be set to 'PS'). In this case, the variance of estimators is obtained by boostrapping.\n")
 
   old_options_warn <- base::options()$warn
   on.exit(base::options(warn = old_options_warn))
@@ -94,8 +94,6 @@ admix_test <- function(samples, admixMod, test_method = c("poly","icv"), conf_le
   } else stop("Please choose appropriately the arguments of the function.")
 
   class(test_res) <- c(specific_class, "htest")
-  #class(test_res) <- "htest"
   test_res$call <- match.call()
   return(test_res)
 }
-
