@@ -15,7 +15,7 @@ mixt1 <- twoComp_mixt(n = 400, weight = 0.7,
                       comp.dist = list("norm", "norm"),
                       comp.param = list(c("mean" = 3, "sd" = 0.5),
                                         c("mean" = 0, "sd" = 1)))
-data1 <- getmixtData(mixt1)
+data1 <- get_mixture_data(mixt1)
 ## Define the admixture model:
 admixMod <- admix_model(knownComp_dist = mixt1$comp.dist[[2]],
                         knownComp_param = mixt1$comp.param[[2]])
@@ -34,8 +34,8 @@ mixt2 <- twoComp_mixt(n = 380, weight = 0.7,
                       comp.dist = list("norm", "norm"),
                       comp.param = list(list("mean" = -2, "sd" = 0.5),
                                         list("mean" = 1, "sd" = 1)))
-data1 <- getmixtData(mixt1)
-data2 <- getmixtData(mixt2)
+data1 <- get_mixture_data(mixt1)
+data2 <- get_mixture_data(mixt2)
 ## Define the admixture models:
 admixMod1 <- admix_model(knownComp_dist = mixt1$comp.dist[[2]],
                          knownComp_param = mixt1$comp.param[[2]])
@@ -54,8 +54,8 @@ mixt2 <- twoComp_mixt(n = 600, weight = 0.7,
                       comp.dist = list("norm", "norm"),
                       comp.param = list(list("mean" = 3, "sd" = 0.5),
                                         list("mean" = 5, "sd" = 2)))
-data1 <- getmixtData(mixt1)
-data2 <- getmixtData(mixt2)
+data1 <- get_mixture_data(mixt1)
+data2 <- get_mixture_data(mixt2)
 ## Define the admixture models:
 admixMod1 <- admix_model(knownComp_dist = mixt1$comp.dist[[2]],
                          knownComp_param = mixt1$comp.param[[2]])
@@ -79,8 +79,8 @@ mixt2 <- twoComp_mixt(n = 700, weight = 0.6,
                       comp.dist = list("norm", "norm"),
                       comp.param = list(list("mean" = 3, "sd" = 0.5),
                                         list("mean" = 5, "sd" = 2)))
-data1 <- getmixtData(mixt1)
-data2 <- getmixtData(mixt2)
+data1 <- get_mixture_data(mixt1)
+data2 <- get_mixture_data(mixt2)
 ## Define the admixture models:
 admixMod1 <- admix_model(knownComp_dist = mixt1$comp.dist[[2]],
                          knownComp_param = mixt1$comp.param[[2]])
@@ -89,7 +89,7 @@ admixMod2 <- admix_model(knownComp_dist = mixt2$comp.dist[[2]],
 ## Estimation:
 est <- admix_estim(samples = list(data1,data2), admixMod = list(admixMod1,admixMod2),
                    est_method = 'PS')
-prop <- getmixingWeight(est)
+prop <- get_mixing_weights(est)
 ## Determine the decontaminated version of the unknown density by inversion:
 res1 <- decontaminated_density(sample1 = data1, estim.p = prop[1], admixMod = admixMod1)
 res2 <- decontaminated_density(sample1 = data2, estim.p = prop[2], admixMod = admixMod2)
